Mean-centers and rescales raw layout coordinates to a fixed pixel range suitable for Cytoscape.js.
Usage
scaleLayoutForCytoscape(x, y, range = c(-500, 500))Mean-centers and rescales raw layout coordinates to a fixed pixel range suitable for Cytoscape.js.
scaleLayoutForCytoscape(x, y, range = c(-500, 500))