Generate Node Attributes for a Complex Network
Source:R/generateNodeAttributes.R
generateNodeAttributes.RdCreates a detailed attribute table for each complex, emphasizing functional specificity for network visualization, and assigns professional HCL colors.
Usage
generateNodeAttributes(
complexes,
enrichments,
geneSetDb = NULL,
similarityMethod = "jaccard",
verbose = TRUE
)